# PERF03-BP02: Make decisions based on access patterns

## Description

Select storage based on hot vs cold data patterns.

## Implementation Guidance

- Analyze data access frequency
- Identify hot, warm, cold data
- Match storage tier to access pattern
- Implement lifecycle policies
- Optimize for common queries

## Risk Level

Medium - Mismatched storage increases cost and latency.

## Related Best Practices

- [PERF03-BP01](PERF03-BP01-Storage-Characteristics.md)
- [PERF03-BP04](PERF03-BP04-Select-Storage-Options.md)
